@@ -1,7 +1,20 @@
-import bugsnag
 from django.conf import settings
-import django
-import os
+
+import bugsnag
+
+
+def get_user_id(request):
+    return request.META['REMOTE_ADDR']
+
+
+def is_development_server(request):
+    server = request.META.get('wsgi.file_wrapper', None)
+
+    if server is None:
+        return False
+
+    return server.__module__ == 'django.core.servers.basehttp'
+
 
 class BugsnagMiddleware(object):
     def __init__(self):
@@ -11,16 +24,16 @@ class BugsnagMiddleware(object):
         # Import Bugsnag settings from settings.py
         django_bugsnag_settings = getattr(settings, 'BUGSNAG', {})
         bugsnag.configure(**django_bugsnag_settings)
-    
-    def process_request(self, request):
-        try:
-            server = request.META.get('wsgi.file_wrapper', None)
-            if server is not None and server.__module__ == 'django.core.servers.basehttp':
-                bugsnag.configure(release_stage="development")
 
+    # pylint: disable-msg=R0201
+    def process_request(self, request):
+        if is_development_server(request):
+            bugsnag.configure(release_stage="development")
+
+        try:
             bugsnag.configure_request(
                 context=request.path,
-                user_id=request.user.username if request.user.is_authenticated() else request.META['REMOTE_ADDR'],
+                user_id=get_user_id(request),
                 session_data=dict(request.session),
                 request_data={
                     'path': request.path,
@@ -30,22 +43,25 @@ class BugsnagMiddleware(object):
                 },
                 environment_data=dict(request.META),
             )
-        except Exception, exc:
+
+        except Exception as exc:
             bugsnag.log("Error in request middleware: %s" % exc)
 
         return None
 
+    # pylint: disable-msg=W0613
     def process_response(self, request, response):
         bugsnag.clear_request_config()
-        
+
         return response
 
     def process_exception(self, request, exception):
         try:
             bugsnag.auto_notify(exception)
-        except Exception, exc:
+
+        except Exception as exc:
             bugsnag.log("Error in exception middleware: %s" % exc)
 
         bugsnag.clear_request_config()
 
-        return None
\ No newline at end of file
+        return None
